summaryrefslogtreecommitdiff
path: root/formula
diff options
context:
space:
mode:
authorEike Rathke [er] <erAck@sun.com>2010-07-16 20:13:45 +0200
committerEike Rathke [er] <erAck@sun.com>2010-07-16 20:13:45 +0200
commit5a111ed13fa5aad3e5a096db5f8cf413b30611e2 (patch)
tree95e967fc99d2716d6b5b0e747023dbaec9700dd4 /formula
parent8d6c8317b9f409c67192568f669e48e5e5dc5fd1 (diff)
calc56: #i108385# make TEXT return text if text was passed, handling text formats that include a @ code
Diffstat (limited to 'formula')
-rw-r--r--formula/inc/formula/errorcodes.hxx8
1 files changed, 7 insertions, 1 deletions
diff --git a/formula/inc/formula/errorcodes.hxx b/formula/inc/formula/errorcodes.hxx
index f9b04e012f..1593f710b4 100644
--- a/formula/inc/formula/errorcodes.hxx
+++ b/formula/inc/formula/errorcodes.hxx
@@ -64,7 +64,8 @@ const USHORT errInterpOverflow = 527;
// Not displayed, temporary for TrackFormulas,
// Cell depends on another cell that has errCircularReference
const USHORT errTrackFromCircRef = 528;
// Interpreter internal: existing cell has no value but value queried
const USHORT errCellNoValue = 529;
// Interpreter: needed AddIn not found
const USHORT errNoAddin = 530;
@@ -74,6 +75,11 @@ const USHORT errNoMacro = 531;
const USHORT errDivisionByZero = 532; // #DIV/0!
// Compiler: a non-simple (str,err,val) value was put in an array
const USHORT errNestedArray = 533;
+// ScInterpreter internal: no numeric value but numeric queried. If this is
+// temporarily (!) set as mnStringNoValueError, the error is generated and can
+// be used to distinguish that condition from all other (inherited) errors. Do
+// not use for anything else! Never push or inherit the error otherwise!
+const USHORT errNotNumericString = 534;
// Interpreter: NA() not available condition, not a real error
const USHORT NOTAVAILABLE = 0x7fff;
@@ -64,7 +64,8 @@ const USHORT errInterpOverflow = 527;
// Cell depends on another cell that has errCircularReference
const USHORT errTrackFromCircRef = 528;
-// Interpreter internal: existing cell has no value but value queried
+// ScInterpreter internal: no numeric value but numeric queried. If this is
+// set as mnStringNoValueError no error is generated but 0 returned.
const USHORT errCellNoValue = 529;
// Interpreter: needed AddIn not found